"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const api_1 = require("./../../commands/api");
const io_1 = require("./../../testing/io");
const io_2 = require("./../../utils/io");
const commandName = api_1.default.name;
describe("Command Api", () => {
    beforeEach(async (done) => {
        await io_1.testSetup(commandName);
        done();
    });
    afterEach(async (done) => {
        await io_1.tearDown(commandName);
        done();
    });
    describe("File Scaffolding", () => {
        it("should create an api file", async (done) => {
            await api_1.default.command({ args: { name: "foo" }, flags: { force: false } });
            const isExisting = await io_2.exists(path.join(io_1.getTestingDirPath(commandName), "src/api/foo.js"));
            expect(isExisting).toEqual(true);
            done();
        });
        it("should create an api test file", async (done) => {
            await api_1.default.command({ args: { name: "foo" }, flags: { force: false } });
            const isExisting = await io_2.exists(path.join(io_1.getTestingDirPath(commandName), "src/api/__tests__/foo.test.js"));
            expect(isExisting).toEqual(true);
            done();
        });
        it("should create a TS api file", async (done) => {
            await api_1.default.command({ args: { name: "bar" }, flags: { force: false, typescript: true } });
            const isExisting = await io_2.exists(path.join(io_1.getTestingDirPath(commandName), "src/api/bar.ts"));
            expect(isExisting).toEqual(true);
            done();
        });
    });
    describe("Pathing", () => {
        it("should dry-run the file at the standard location", async (done) => {
            // Arrange
            const infoActual = console.info;
            console.info = jest.fn();
            // Act
            await api_1.default.command({ args: { name: "foo" }, flags: { force: false, "dry-run": true } });
            // Assert
            expect(console.info.mock.calls[0][0]).toContain("./src/api/foo.js");
            done();
            // Clean up
            console.info = infoActual;
        });
        it("should dry-run the file at a custom location", async (done) => {
            // Arrange
            const infoActual = console.info;
            console.info = jest.fn();
            // Act
            await api_1.default.command({ args: { name: "custom/shared/foo" }, flags: { force: false, "dry-run": true } });
            // Assert
            expect(console.info.mock.calls[0][0]).toContain("./src/custom/shared/foo.js");
            done();
            // Clean up
            console.info = infoActual;
        });
    });
});
