"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const node_1 = require("./../../commands/node");
const io_1 = require("./../../testing/io");
const commandName = node_1.default.name;
describe("Command Api", () => {
    beforeEach(async (done) => {
        await io_1.testSetup(commandName);
        done();
    });
    afterEach(async (done) => {
        await io_1.tearDown(commandName);
        done();
    });
    describe("Pathing", () => {
        it("should dry-run the file at the standard location", async (done) => {
            // Arrange
            const infoActual = console.info;
            console.info = jest.fn();
            // Act
            await node_1.default.command({ args: { command: "module", arg: "foo" }, flags: { force: false, "dry-run": true } });
            // Assert
            expect(console.info.mock.calls[0][0]).toContain("./src/modules/foo.js");
            done();
            // Clean up
            console.info = infoActual;
        });
        it("should dry-run the file at a custom location", async (done) => {
            // Arrange
            const infoActual = console.info;
            console.info = jest.fn();
            // Act
            await node_1.default.command({ args: { command: "module", arg: "custom/foo" }, flags: { force: false, "dry-run": true } });
            // Assert
            expect(console.info.mock.calls[0][0]).toContain("./src/custom/foo.js");
            done();
            // Clean up
            console.info = infoActual;
        });
    });
});
