"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const installer_1 = require("./../engine/installer");
const detection_1 = require("./../utils/detection");
const flags_1 = require("./../utils/flags");
const format_1 = require("./../utils/format");
const pathing_1 = require("./../utils/pathing");
class Api extends command_1.Command {
    async run() {
        await Api.command(this.parse(Api));
    }
    static async command({ args, flags }) {
        if (args.name) {
            await Api.action(args.name, flags);
            return;
        }
        console.info("You must provide the name of the api");
    }
    static async action(nameArg, flags) {
        const isTypescript = detection_1.isTypescriptProject(flags);
        const { name, dirPath } = pathing_1.resolvePath("api", nameArg);
        // Files
        const stampVars = {
            name,
            nameProperCase: format_1.toProperCase(name)
        };
        const files = [
            isTypescript // no-prettier
                ? ["/api/typescript", dirPath, stampVars]
                : ["/api/javascript", dirPath, stampVars]
        ];
        // Packages
        let devPackages = ["nock", "node-fetch"];
        const prodPackages = ["validate"];
        if (isTypescript) {
            devPackages = [...devPackages, "@types/node-fetch"];
        }
        // Install
        await installer_1.install(files, devPackages, prodPackages, flags);
    }
}
exports.default = Api;
Api.docs = {
    description: "Sub CLI for api generator. " + "Creates fetch calls with a try / catch wrapper.",
    descriptionShort: "Sub cli for api generator",
    commands: [
        {
            summary: "Creates an interface for talking with a rest endpoint. " +
                "It will generate a file that uses fetch with a try/catch wrapper, schema validation, logging and unit test boiler plate.",
            summaryShort: "Create an api call helper",
            command: "tmpl api [name]"
        },
        {
            summary: "Creates an interface for talking with a rest endpoint. " +
                "It will generate a file that uses fetch with a try/catch wrapper, schema validation and logging.  " +
                "Force Typescript.",
            summaryShort: "Create an api call helper, force ts",
            command: "tmpl api [name] -t"
        }
    ]
};
// OCLIF readme gen
Api.description = Api.docs.descriptionShort;
Api.examples = format_1.docCommandsToExamples(Api.docs.commands);
Api.flags = Object.assign(Object.assign(Object.assign({}, flags_1.standardFlags), flags_1.javascriptFlags), flags_1.installFlag);
Api.args = [{ name: "name" }];
