"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const child_process_1 = require("child_process");
const util_1 = require("util");
const installer_1 = require("./../engine/installer");
const flags_1 = require("../utils/flags");
const format_1 = require("./../utils/format");
class Git extends command_1.Command {
    async run() {
        Git.command(this.parse(Git));
    }
    static async command({ args, flags }) {
        switch (args.command) {
            case "csharp":
                await Git.csharpAction(flags);
                break;
            default:
                await Git.generalAction(flags);
                break;
        }
    }
    static async csharpAction(flags) {
        // Files
        const files = [["/git/csharp", "."]];
        // Install
        await installer_1.install(files, [], [], flags);
        await Git.gitInit();
    }
    static async generalAction(flags) {
        // Files
        const files = [["/git/general", "."]];
        // Install
        await installer_1.install(files, [], [], flags);
        await Git.gitInit();
    }
    static async gitInit() {
        await util_1.promisify(child_process_1.exec)(`git init && git add . && git commit -m "Initial commit"`);
    }
}
exports.default = Git;
Git.docs = {
    description: "",
    descriptionShort: "Sub Cli to Create gitignores and init commits",
    commands: [
        {
            summary: "Creates a general .gitignore and inits",
            summaryShort: "Creates a general .gitignore and inits",
            command: "tmpl git"
        },
        {
            summary: "Creates a csharp .gitignore and inits",
            summaryShort: "Creates a csharp .gitignore and inits",
            command: "tmpl git csharp"
        }
    ]
};
// OCLIF readme gen
Git.description = Git.docs.descriptionShort;
Git.examples = format_1.docCommandsToExamples(Git.docs.commands);
Git.flags = Object.assign(Object.assign({}, flags_1.installFlag), flags_1.standardFlags);
Git.args = [{ name: "command" }];
