"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const installer_1 = require("./../engine/installer");
const generate_1 = require("./../generators/jest/generate");
const flags_1 = require("./../utils/flags");
const format_1 = require("./../utils/format");
const detection_1 = require("./../utils/detection");
class Jest extends command_1.Command {
    async run() {
        const { flags } = this.parse(Jest);
        await this.initialize(flags);
    }
    async initialize(flags) {
        // Prompt
        const options = {
            isTypescript: detection_1.isTypescriptProject(flags)
        };
        // Generators
        const { files, devPackages, prodPackages } = generate_1.generateJest(options);
        // Install
        await installer_1.install(files, devPackages, prodPackages, flags);
    }
}
exports.default = Jest;
Jest.docs = {
    description: "Creates a jest.config.js file in the current directory and installs deps",
    descriptionShort: "Sub cli for jest install",
    commands: [
        {
            summary: "Sub CLI for jest install. " + "Creates a jest.config.js and installs.",
            summaryShort: "Creates a jest.config.js and installs",
            command: "tmpl jest"
        },
        {
            summary: "Sub CLI for jest install. " + "Creates a jest.config.js and installs.  " + "Force typescript",
            summaryShort: "Creates a jest.config.js and installs",
            command: "tmpl jest -t"
        }
    ]
};
// OCLIF readme gen
Jest.description = Jest.docs.descriptionShort;
Jest.examples = format_1.docCommandsToExamples(Jest.docs.commands);
Jest.flags = Object.assign(Object.assign(Object.assign({}, flags_1.standardFlags), flags_1.javascriptFlags), flags_1.installFlag);
Jest.args = [{ name: "command" }, { name: "arg" }];
