"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const installer_1 = require("./../engine/installer");
const fragments_1 = require("./../templates/prettier/fragments");
const detection_1 = require("./../utils/detection");
const flags_1 = require("./../utils/flags");
const format_1 = require("./../utils/format");
class Prettier extends command_1.Command {
    async run() {
        const { flags } = this.parse(Prettier);
        await this.action(flags);
    }
    async action(flags) {
        // Files
        const stampVars = {
            eslintTsParser: detection_1.isTypescriptProject() ? fragments_1.eslintTsParser : ""
        };
        const files = [["/prettier/core", ".", stampVars]];
        // Packages
        let devPackages = [
            "prettier",
            "eslint",
            "eslint-config-prettier",
            "eslint-plugin-prettier",
            "eslint-plugin-jest",
            "eslint-plugin-jsx-a11y"
        ];
        if (detection_1.isTypescriptProject()) {
            devPackages = [...devPackages, "typescript", "@typescript-eslint/parser"];
        }
        // Install
        await installer_1.install(files, devPackages, [], flags);
    }
}
exports.default = Prettier;
Prettier.docs = {
    description: "",
    descriptionShort: "Sub cli for prettier",
    commands: [
        {
            summary: "Sub cli for prettier. " + "Installs prettier with eslint bridge to vscode",
            summaryShort: "Installs prettier with eslint bridge to vscode",
            command: "tmpl prettier"
        }
    ]
};
// OCLIF readme gen
Prettier.description = Prettier.docs.descriptionShort;
Prettier.examples = format_1.docCommandsToExamples(Prettier.docs.commands);
Prettier.flags = Object.assign(Object.assign({}, flags_1.standardFlags), flags_1.installFlag);
Prettier.args = [{ name: "command" }, { name: "arg" }];
