"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const installer_1 = require("./../engine/installer");
const flags_1 = require("./../utils/flags");
const detection_1 = require("./../utils/detection");
const format_1 = require("./../utils/format");
class Schema extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Schema);
        if (args.name) {
            await this.action(args.name, flags);
            return;
        }
        this.log("You must provide the name of the schema");
    }
    async action(schemaName, flags) {
        // Files
        const stampVars = {
            schemaName: `${schemaName}Schema`
        };
        const files = [
            detection_1.isTypescriptProject(flags)
                ? ["/schema/typescript", "./src/data/schemas", stampVars]
                : ["/schema/javascript", "./src/data/schemas", stampVars]
        ];
        // Packages
        const prodPackages = ["validate"];
        // Install
        await installer_1.install(files, [], prodPackages, flags);
    }
}
exports.default = Schema;
Schema.docs = {
    description: "",
    descriptionShort: "Sub cli for schema generator",
    commands: [
        {
            summary: "Creates a schema.",
            summaryShort: "Creates a schema",
            command: "tmpl schema [name]"
        }
    ]
};
// OCLIF readme gen
Schema.description = Schema.docs.descriptionShort;
Schema.examples = format_1.docCommandsToExamples(Schema.docs.commands);
Schema.flags = Object.assign(Object.assign({}, flags_1.installFlag), flags_1.standardFlags);
Schema.args = [{ name: "name" }];
