"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const installer_1 = require("./../engine/installer");
const flags_1 = require("./../utils/flags");
const format_1 = require("./../utils/format");
class Style extends command_1.Command {
    async run() {
        await Style.command(this.parse(Style));
    }
    static async command({ args, flags }) {
        switch (args.command) {
            case "reset":
                await Style.resetAction(flags);
                break;
            case "breakpoints":
                await Style.breakpointsAction(flags);
                break;
            case "colors":
                await Style.colorsAction(flags);
                break;
            case "colors-tw":
            case "colors-tailwind":
                await Style.colorsTailwindAction(flags);
                break;
            case "sakura":
                await Style.sakuraAction(flags);
                break;
            case "water":
                await Style.waterAction(flags);
                break;
            default:
                console.log("No matching subcommand was provided");
        }
    }
    static async resetAction(flags) {
        const files = [["/style/reset", "."]];
        await installer_1.install(files, [], [], flags);
    }
    static async breakpointsAction(flags) {
        const files = [["/style/breakpoints", "."]];
        await installer_1.install(files, [], [], flags);
    }
    static async colorsAction(flags) {
        const files = [["/style/colors", "."]];
        await installer_1.install(files, [], [], flags);
    }
    static async colorsTailwindAction(flags) {
        const files = [["/style/colorsTailwind", "."]];
        await installer_1.install(files, [], [], flags);
    }
    static async sakuraAction(flags) {
        const files = [["/style/sakura", "."]];
        await installer_1.install(files, [], [], flags);
    }
    static async waterAction(flags) {
        const files = [["/style/water", "."]];
        await installer_1.install(files, [], [], flags);
    }
}
exports.default = Style;
Style.docs = {
    description: "",
    descriptionShort: "Sub cli for Style templates",
    commands: [
        {
            summary: "Creates a css reset file.",
            summaryShort: "Creates a css reset file",
            command: "tmpl style reset"
        },
        {
            summary: "Creates a css colors file.",
            summaryShort: "Creates a css colors file",
            command: "tmpl style colors"
        },
        {
            summary: "Creates a css colors-tailwind file.",
            summaryShort: "Creates a css colors-tailwind file",
            command: "tmpl style colors-tailwind"
        },
        {
            summary: "Creates a css file to import sakura.",
            summaryShort: "Creates a css file to import sakura",
            command: "tmpl style sakura"
        },
        {
            summary: "Creates a css file to import water.",
            summaryShort: "Creates a css file to import water",
            command: "tmpl style water"
        }
    ]
};
// OCLIF readme gen
Style.description = Style.docs.descriptionShort;
Style.examples = format_1.docCommandsToExamples(Style.docs.commands);
Style.flags = Object.assign(Object.assign({}, flags_1.installFlag), flags_1.standardFlags);
Style.args = [{ name: "command" }, { name: "arg" }];
