"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const installer_1 = require("./../engine/installer");
const detection_1 = require("./../utils/detection");
const flags_1 = require("./../utils/flags");
const format_1 = require("./../utils/format");
class Util extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Util);
        switch (args.command) {
            case "async":
                await this.asyncAction(flags);
                break;
            case "cookie":
                await this.cookieAction(flags);
                break;
            case "dynamic":
                await this.dynamicAction(flags);
                break;
            case "event-listener":
            case "event-listener-reg":
            case "eventlistener":
            case "eventlistenerreg":
                await this.eventListenerRegAction(flags);
                break;
            case "history":
                await this.historyAction(flags);
                break;
            case "polyfills":
                await this.polyfillsAction(flags);
                break;
            case "react":
                await this.reactAction(flags);
                break;
            default:
                this.log("No subcommand was provided");
        }
    }
    async asyncAction(flags) {
        // Files
        const files = [
            detection_1.isTypescriptProject(flags) ? ["/util/async/typescript", "/src/utils"] : ["/util/async/javascript", "/src/utils"]
        ];
        // Install
        await installer_1.install(files, [], [], flags);
    }
    async cookieAction(flags) {
        // Files
        const files = [
            detection_1.isTypescriptProject(flags) ? ["/util/cookie/typescript", "/src/utils"] : ["/util/cookie/javascript", "/src/utils"]
        ];
        // Install
        await installer_1.install(files, [], [], flags);
    }
    async dynamicAction(flags) {
        // Files
        const files = [
            detection_1.isTypescriptProject(flags)
                ? ["/util/dynamic/typescript", "/src/utils"]
                : ["/util/dynamic/javascript", "/src/utils"]
        ];
        // Install
        await installer_1.install(files, [], [], flags);
    }
    async eventListenerRegAction(flags) {
        // Files
        const files = [
            detection_1.isTypescriptProject(flags)
                ? ["/util/eventListenerReg/typescript", "/src/utils"]
                : ["/util/eventListenerReg/javascript", "/src/utils"]
        ];
        // Install
        await installer_1.install(files, [], [], flags);
    }
    async historyAction(flags) {
        // Files
        const files = [
            detection_1.isTypescriptProject(flags)
                ? ["/util/history/typescript", "/src/utils"]
                : ["/util/history/javascript", "/src/utils"]
        ];
        // Install
        await installer_1.install(files, [], [], flags);
    }
    async polyfillsAction(flags) {
        // Files
        const files = [
            detection_1.isTypescriptProject(flags)
                ? ["/util/polyfills/typescript", "/src/utils"]
                : ["/util/polyfills/javascript", "/src/utils"]
        ];
        // Packages
        const prodPackages = ["isomorphic-fetch"];
        // Install
        await installer_1.install(files, [], prodPackages, flags);
    }
    async reactAction(flags) {
        // Files
        const files = [
            detection_1.isTypescriptProject(flags) ? ["/util/react/typescript", "/src/utils"] : ["/util/react/javascript", "/src/utils"]
        ];
        // Packages
        let devPackages = detection_1.isTypescriptProject(flags) ? ["@types/react", "@types/react-dom"] : ["@babel/preset-react"];
        const prodPackages = ["react", "react-dom"];
        // Install
        await installer_1.install(files, devPackages, prodPackages, flags);
        // Info
        if (!detection_1.isTypescriptProject(flags)) {
            this.log("FYI: You must add @babel/preset-react to the babel presets");
            this.log('Example:\n{\n  "presets": ["@babel/preset-react"]\n}');
        }
    }
}
exports.default = Util;
Util.docs = {
    description: "Sub cli for util helps.",
    descriptionShort: "Sub cli for util helps",
    commands: [
        {
            summary: "Adds async util.",
            summaryShort: "Adds async util",
            command: "tmpl util async"
        },
        {
            summary: "Adds cookie util.",
            summaryShort: "Adds cookie util",
            command: "tmpl util cookie"
        },
        {
            summary: "Adds dynamic util.",
            summaryShort: "Adds dynamic util",
            command: "tmpl util dynamic"
        },
        {
            summary: "Adds event-listener util.",
            summaryShort: "Adds event-listener util",
            command: "tmpl util event-listener"
        },
        {
            summary: "Adds history util.",
            summaryShort: "Adds history util",
            command: "tmpl util history"
        },
        {
            summary: "Adds polyfills util.",
            summaryShort: "Adds polyfills util",
            command: "tmpl util polyfills"
        },
        {
            summary: "Adds react util.",
            summaryShort: "Adds react util",
            command: "tmpl util react"
        }
    ]
};
// OCLIF readme gen
Util.description = Util.docs.descriptionShort;
Util.examples = format_1.docCommandsToExamples(Util.docs.commands);
Util.flags = Object.assign(Object.assign(Object.assign({}, flags_1.standardFlags), flags_1.installFlag), flags_1.javascriptFlags);
Util.args = [{ name: "command" }, { name: "arg" }];
