"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const inquirer_1 = require("inquirer");
const installer_1 = require("./../engine/installer");
const generate_1 = require("./../generators/webpack/generate");
const flags_1 = require("./../utils/flags");
class Webpack extends command_1.Command {
    async run() {
        const { flags } = this.parse(Webpack);
        await this.initialize(flags);
    }
    async initialize(flags) {
        const opt = await this.initializePrompt();
        // Generators
        const webpackGen = await generate_1.generateWebpack(opt);
        const files = webpackGen.files;
        const devPackages = webpackGen.devPackages;
        const prodPackages = webpackGen.prodPackages;
        // Install
        await installer_1.install(files, devPackages, prodPackages, flags);
    }
    async initializePrompt() {
        const { options } = await inquirer_1.prompt({
            type: "checkbox",
            message: "Please select your options",
            name: "options",
            choices: [
                {
                    name: "Typescript",
                    value: "typescript"
                },
                {
                    name: "SCSS",
                    value: "sass"
                }
            ]
        });
        return {
            isBabel: options.indexOf("typescript") === -1,
            isSass: options.indexOf("sass") > -1,
            isTypescript: options.indexOf("typescript") > -1
        };
    }
}
exports.default = Webpack;
Webpack.description = "Creates webpack.config.js and installs deps";
Webpack.examples = [
    `$ tmpl webpack
`
];
Webpack.flags = Object.assign(Object.assign(Object.assign({}, flags_1.installFlag), flags_1.standardFlags), flags_1.javascriptFlags);
Webpack.args = [{ name: "command" }, { name: "arg" }];
