"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.determineNpmVersions = exports.npmInstallProd = exports.npmInstallDev = void 0;
const cli_ux_1 = require("cli-ux");
const child_process_1 = require("child_process");
const util_1 = require("util");
const path = require("path");
const fs_1 = require("fs");
const io_1 = require("./../utils/io");
const getPackagePath = (directory = ".") => path.join(directory, "package.json");
const filterOutInstalled = (depProperty, packages, directory = ".") => packages.filter(packageName => {
    const npmData = JSON.parse(fs_1.readFileSync(getPackagePath(directory), "utf8"));
    return !Boolean(npmData[depProperty] && npmData[depProperty][packageName]);
});
const npmInstallActive = async (depProperty, commandFlag, packages, directory = ".") => {
    const packagesToInstall = filterOutInstalled(depProperty, packages, directory);
    return (packagesToInstall.length > 0 &&
        (await util_1.promisify(child_process_1.exec)(`cd ${directory} && npm install ${commandFlag} ${packagesToInstall.join(" ")}`)));
};
const npmInstallPassive = async (depProperty, packages, directory = ".") => {
    const packagePath = path.join(directory, "package.json");
    if (fs_1.existsSync(packagePath)) {
        const npmData = JSON.parse(fs_1.readFileSync(packagePath, "utf8"));
        const existingDependencies = npmData[depProperty] || {};
        const newDependencies = Object.assign(Object.assign({}, existingDependencies), (await exports.determineNpmVersions(packages.sort())));
        npmData[depProperty] = newDependencies;
        fs_1.writeFileSync(packagePath, JSON.stringify(npmData), "utf8");
        io_1.prettyFile(packagePath);
    }
};
exports.npmInstallDev = async (packages, flags, directory = ".") => {
    cli_ux_1.default.action.start(flags.install ? "Installing NPM dev dependencies..." : "Adding package dev dependencies without install...");
    flags.install
        ? await npmInstallActive("devDependencies", "--save-dev", packages, directory)
        : await npmInstallPassive("devDependencies", packages, directory);
    cli_ux_1.default.action.stop();
};
exports.npmInstallProd = async (packages, flags, directory = ".") => {
    cli_ux_1.default.action.start(flags.install ? "Installing NPM dependencies..." : "Adding package dependencies without install...");
    flags.install
        ? await npmInstallActive("dependencies", "--save", packages, directory)
        : await npmInstallPassive("dependencies", packages, directory);
    cli_ux_1.default.action.stop();
};
exports.determineNpmVersions = async (packages) => {
    const packageVersions = await packages.reduce(async (accP, curr) => {
        const acc = await accP;
        const response = (await util_1.promisify(child_process_1.exec)(`npm show ${curr} version`)).stdout;
        const version = `^${response.replace("\n", "")}`;
        const packageName = curr.split(/@[\^0-9]/)[0]; // Remove @^ if it concats...
        acc[packageName] = version;
        return acc;
    }, {});
    return packageVersions;
};
