"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.stageAndScaffold = void 0;
const chalk = require("chalk");
const fs_1 = require("fs");
const rimraf = require("rimraf");
const readDir = require("recursive-readdir");
const templator_1 = require("./../engine/templator");
const constants_1 = require("./../utils/constants");
const io_1 = require("./../utils/io");
const format_1 = require("./../utils/format");
const io_2 = require("./../utils/io");
const stampTemplate = (inDir, outDir = ".", vars = {}) => new Promise((resolve, reject) => {
    templator_1.applyTemplate(inDir, outDir, vars, (error, createdFiles) => {
        if (error) {
            reject(error);
        }
        resolve(createdFiles);
    });
});
const createStagingDir = async (projectPath = ".") => {
    try {
        await fs_1.promises.mkdir(`${projectPath}/${constants_1.templatingStagingDirName}`);
    }
    catch (err) { }
};
const removeStagingDir = (projectPath = ".") => new Promise(resolve => rimraf(`${projectPath}/${constants_1.templatingStagingDirName}`, resolve));
const findOverwriteConflicts = async (filePaths) => {
    const existsWithHoles = await Promise.all(filePaths.map(async (fp) => {
        const target = fp.replace(`${constants_1.templatingStagingDirName}`, ".");
        return (await io_1.exists(target)) ? target : undefined;
    }));
    return existsWithHoles.filter(fp => Boolean(fp));
};
const stageFiles = async (stampTuple, destBasePath = ".") => {
    const stagingPath = `${destBasePath}/${constants_1.templatingStagingDirName}`;
    for (const st of stampTuple) {
        await stampTemplate(`${io_1.templatesDir}/${st[0]}`, `${stagingPath}/${st[1]}`, st[2]);
    }
    return readDir(`${stagingPath}`);
};
const getFileSize = async (filePath) => {
    try {
        return (await fs_1.promises.stat(filePath)).size;
    }
    catch (err) {
        return "??";
    }
};
const copyFiles = async (stagedFiles, existingFiles, isDryRun) => {
    for (const fp of stagedFiles) {
        const target = fp.replace(constants_1.templatingStagingDirName, ".");
        const size = await getFileSize(fp);
        if (!isDryRun) {
            await io_1.copyDrill(fp, target);
        }
        const action = existingFiles.indexOf(target) > -1 ? chalk.yellow("OVERWRITE ") : chalk.green("CREATE ");
        console.info(action + target + ` (${size} bytes)`);
    }
};
const prettyStaged = async (dirPath) => {
    const filePaths = await readDir(dirPath);
    for (const fp of filePaths) {
        const extensions = [".js", ".jsx", ".ts", ".tsx"];
        if (extensions.indexOf(format_1.getExtension(fp)) > -1) {
            await io_2.prettyFile(fp);
        }
    }
};
exports.stageAndScaffold = async (stampTuple, flags, destBasePath = ".") => {
    let isSuccess = false;
    try {
        createStagingDir(destBasePath);
        const stagedFiles = await stageFiles(stampTuple, destBasePath);
        const overwriteConflicts = await findOverwriteConflicts(stagedFiles);
        await prettyStaged(`${process.cwd()}/${constants_1.templatingStagingDirName}`);
        if (overwriteConflicts.length === 0 || flags["dry-run"] || flags.force) {
            await copyFiles(stagedFiles, overwriteConflicts, Boolean(flags["dry-run"]));
            isSuccess = true;
        }
        else {
            console.info("Files exist, aborting templating, use the -f flag to force overwrite conflicts");
            console.info(overwriteConflicts);
        }
        if (flags["dry-run"]) {
            console.info(chalk.yellow("\nThis was a dry run. To apply the code generation, re-run without the -d flag\n"));
        }
        await removeStagingDir(destBasePath);
        return isSuccess;
    }
    catch (err) { }
};
