"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.genComponentConnected = exports.genComponentDefinition = exports.genDefaultProps = exports.genInterfaceProps = exports.genImportMobxStore = exports.genImportContext = exports.genImportLibrary = void 0;
const transforms_1 = require("../../../utils/transforms");
exports.genImportLibrary = (opt) => transforms_1.arrayToLines([
    `import React ${opt.contextName ? ", { useContext } " : ""}from "react";`,
    opt.mobxName ? 'import { observer } from "mobx-react"' : undefined
]);
exports.genImportContext = (opt) => opt.contextName
    ? transforms_1.arrayToLines([
        "import {",
        opt.isTypescript ? `  I${opt.contextNameProperCase}Actions,` : undefined,
        opt.isTypescript ? `  I${opt.contextNameProperCase}State,` : undefined,
        `  ${opt.contextNameProperCase},`,
        `  ${opt.contextName}EmptyState,`,
        `  ${opt.contextName}EmptyActions,`,
        `} from "@stores/${opt.contextName}";`,
        ""
    ])
    : "";
exports.genImportMobxStore = (opt) => opt.mobxName
    ? opt.isTypescript
        ? `import { ${opt.mobxName}, I${opt.mobxNameProperCase} } from '@stores/${opt.mobxName}';`
        : `import { ${opt.mobxName} } from '@stores/${opt.mobxName}';`
    : "";
exports.genInterfaceProps = (opt) => opt.isTypescript
    ? transforms_1.arrayToLines([
        "",
        "interface IProps {",
        "  propData?: string;",
        opt.mobxName ? `  ${opt.mobxName}?: I${opt.mobxNameProperCase};` : undefined,
        opt.contextName ? `  ${opt.contextNameNoSuffix}Data?: I${opt.contextNameProperCase}State;` : undefined,
        opt.contextName ? `  ${opt.contextNameNoSuffix}Actions?: I${opt.contextNameProperCase}Actions;` : undefined,
        "}",
        ""
    ])
    : "";
exports.genDefaultProps = (opt) => transforms_1.arrayToLines([
    `const defaultProps${opt.isTypescript ? ": IProps" : ""} = {`,
    '  propData: "",',
    opt.contextName ? `  ${opt.contextNameNoSuffix}Actions: ${opt.contextName}EmptyActions,` : undefined,
    opt.contextName ? `  ${opt.contextNameNoSuffix}Data: ${opt.contextName}EmptyState,` : undefined,
    "}"
]);
exports.genComponentDefinition = (opt) => transforms_1.arrayToLines([
    `export const ${opt.nameProperCase}${opt.isTypescript ? ": React.FC<IProps>" : ""} = (props${opt.isTypescript ? ": IProps" : ""}) => {`,
    `  return <div className="${opt.nameKebabCase}" role="none" >`,
    `    -- ${opt.nameProperCase} Component --`,
    `  </div>;`,
    `}`
]);
exports.genComponentConnected = (opt) => {
    switch (true) {
        case Boolean(opt.contextName):
            return transforms_1.arrayToLines([
                "",
                `export const ${opt.name}Connected = () => {`,
                `  const ${opt.contextName} = useContext(${opt.contextNameProperCase});`,
                `  return <${opt.nameProperCase} ${opt.contextNameNoSuffix}Actions={ ${opt.contextName}.actions } ${opt.contextNameNoSuffix}Data={ ${opt.contextName}.state }></${opt.nameProperCase}>;`,
                "};",
                ""
            ]);
        case Boolean(opt.mobxName):
            return transforms_1.arrayToLines([
                "",
                `export const ${opt.nameProperCase}Connected = () => <${opt.nameProperCase} ${opt.mobxName}={${opt.mobxName}}/>;`,
                ""
            ]);
    }
};
