"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateWebpack = void 0;
const preConfig_1 = require("./parts/preConfig");
const target_1 = require("./parts/target");
const entry_1 = require("./parts/entry");
const output_1 = require("./parts/output");
const devServer_1 = require("./parts/devServer");
const packages_1 = require("./packages");
const loaders_1 = require("./parts/loaders");
const plugins_1 = require("./parts/plugins");
const resolve_1 = require("./parts/resolve");
const generate_1 = require("../tsconfig/generate");
const normalizeOptions = (optionsInput) => ({
    isCopyPlugin: false,
    isDotEnv: false,
    isWeb: !optionsInput.isNode,
    isNode: Boolean(optionsInput.isNode),
    isHbs: Boolean(optionsInput.isHbs),
    isCss: !optionsInput.isSass,
    isSass: Boolean(optionsInput.isSass),
    isJavascript: !optionsInput.isTypescript,
    isTypescript: Boolean(optionsInput.isTypescript),
    isReact: Boolean(optionsInput.isReact),
    isVue: Boolean(optionsInput.isVue)
});
exports.generateWebpack = (optionsInput, path = "") => {
    // Options
    const opt = normalizeOptions(optionsInput);
    // Files
    const vars = {
        preConfig: preConfig_1.getPreConfig(opt),
        target: target_1.getTarget(opt),
        entry: entry_1.getEntry(),
        devServer: devServer_1.getDevServer(opt),
        loaders: loaders_1.getLoaders(opt),
        output: output_1.getOutput(opt),
        plugins: plugins_1.getPlugins(opt),
        resolve: resolve_1.getResolve(opt)
    };
    let files = [["/webpack/core", path, vars]];
    // Packages
    let devPackages = packages_1.getDevPackages(opt);
    // Generators
    if (opt.isTypescript) {
        const tsConfigGen = generate_1.generateTsConfig(opt, path);
        files = [...files, ...tsConfigGen.files];
        devPackages = [...devPackages, ...tsConfigGen.devPackages];
    }
    return {
        files,
        devPackages,
        prodPackages: []
    };
};
